@@ -1,9 +1,10 @@
-import datetime
-
 import traceback
 import boto3
 
-#consider: avoid file scope?
+import os
+
+from properly_util_python.environments import get_properly_stage_for_resource
+
 sqs = boto3.client('sqs', )
 
 
@@ -61,8 +62,9 @@ def get_from_queue(queue_name, messages_num=10):
             MessageAttributeNames=[
                 'All'
             ],
-            VisibilityTimeout=0,
-            WaitTimeSeconds=0
+            # Do NOT set visibility and wait timeout to zero
+            # visibility timeout of zero makes the message immediately available for other consumers
+            # doing this increases duplicate processing
         )
 
         return response
@@ -92,14 +94,7 @@ def queue_exists(queue_name):
         print('traceback', traceback.format_exc())
         return False
 
-
-if __name__ == '__main__':
-    message_attributes = {
-        'url': 'https://matrix.crebtools.com/Matrix/Public/Portal.aspx?k=1177309X3H53&p=DE-57004363-968#1'
-    }
-    message_body = 'URl for pre-scraping, added on: %s' % datetime.datetime.now().isoformat()
-    add_to_queue('dev-UrlsForPreScraping', message_attributes, message_body)
-
-    print('add_to_queue', add_to_queue('dev-UrlsForPreScraping', message_attributes, message_body))
-
-    print('get_from_queue()', get_from_queue('dev-UrlsForPreScraping'))
+def queue_full_name(queue_name):
+    stage = get_properly_stage_for_resource(default_stage="dev", use_local=True)
+    queue_name_to_return = "{}-{}".format(stage, queue_name)
+    return queue_name_to_return
